@@ -1,5 +1,4 @@
-"""
-The knowledge base.
+"""The knowledge base.
 
 Knowledge
 =========
@@ -9,10 +8,15 @@ particular modules (``VERSION_ATTRIBUTES``, ``VERSION_METHODS``)
 
 """
 
-import os
+from __future__ import annotations
+
+from pathlib import Path
 import sys
 import sysconfig
-from typing import Callable, Dict, List, Literal, Set, Tuple, Union
+from typing import TYPE_CHECKING, Literal
+
+if TYPE_CHECKING:
+    from collections.abc import Callable
 
 PACKAGE_ALIASES = {
     'vtkmodules': 'vtk',
@@ -36,7 +40,7 @@ def get_pyqt5_version() -> str:
     return PYQT_VERSION_STR
 
 
-VERSION_METHODS: Dict[str, Callable[[], str]] = {
+VERSION_METHODS: dict[str, Callable[[], str]] = {
     'PyQt5': get_pyqt5_version,
 }
 
@@ -49,18 +53,20 @@ def in_ipython() -> bool:
     -------
     bool : True
         ``True`` when in an IPython environment.
+
     """
     try:
-        __IPYTHON__
-        return True
+        __IPYTHON__  # noqa: B018
     except NameError:
         return False
+    else:
+        return True
 
 
 def in_ipykernel() -> bool:
     """Check if in a ipykernel (most likely Jupyter) environment.
 
-    Warning
+    Warning:
     -------
     There is no way to tell if the code is being executed in a notebook
     (Jupyter Notebook or Jupyter Lab) or a kernel is used but executed in a
@@ -68,9 +74,10 @@ def in_ipykernel() -> bool:
     `in_ipykernel` returns True, you are most likely in a Jupyter Notebook/Lab,
     just keep it in mind that there are other possibilities.
 
-    Returns
+    Returns:
     -------
     bool : True if using an ipykernel
+
     """
     ipykernel = False
     if in_ipython():
@@ -81,46 +88,43 @@ def in_ipykernel() -> bool:
     return ipykernel
 
 
-def get_standard_lib_modules() -> Set[str]:
+def get_standard_lib_modules() -> set[str]:
     """Return a set of the names of all modules in the standard library."""
-    site_path = sysconfig.get_path('stdlib')
+    site_path = Path(sysconfig.get_path('stdlib'))
     if getattr(sys, 'frozen', False):  # within pyinstaller
-        lib_path = os.path.join(site_path, '..')
-        if os.path.isdir(lib_path):
-            names = os.listdir(lib_path)
+        lib_path = site_path / '..'
+        if lib_path.is_dir():
+            names = lib_path.iterdir()
+            stdlib_pkgs = {p.stem for p in names if p.suffix == '.py'}
         else:
-            names = []
-
-        stdlib_pkgs = {name[:-3] for name in names if name.endswith(".py")}
+            stdlib_pkgs = {}
 
     else:
-        names = os.listdir(site_path)
+        names = site_path.iterdir()
+        stdlib_pkgs = {p.stem if p.suffix == '.py' else p.name for p in names}
 
-        stdlib_pkgs = set([name if not name.endswith(".py") else name[:-3] for name in names])
-
-    stdlib_pkgs = {
-        "python",
-        "sys",
-        "__builtin__",
-        "__builtins__",
-        "builtins",
-        "session",
-        "math",
-        "itertools",
-        "binascii",
-        "array",
-        "atexit",
-        "fcntl",
-        "errno",
-        "gc",
-        "time",
-        "unicodedata",
-        "mmap",
+    return {
+        'python',
+        'sys',
+        '__builtin__',
+        '__builtins__',
+        'builtins',
+        'session',
+        'math',
+        'itertools',
+        'binascii',
+        'array',
+        'atexit',
+        'fcntl',
+        'errno',
+        'gc',
+        'time',
+        'unicodedata',
+        'mmap',
     }.union(stdlib_pkgs)
-    return stdlib_pkgs
 
 
-def version_tuple(v: str) -> Tuple[int, ...]:
+def version_tuple(v: str) -> tuple[int, ...]:
     """Convert a version string to a tuple containing ints.
 
     Non-numeric version strings will be converted to 0.  For example:
@@ -131,15 +135,17 @@ def version_tuple(v: str) -> Tuple[int, ...]:
     ver_tuple : tuple
         Length 3 tuple representing the major, minor, and patch
         version.
+
     """
-    split_v = v.split(".")
+    split_v = v.split('.')
     while len(split_v) < 3:
         split_v.append('0')
 
     if len(split_v) > 3:
-        raise ValueError('Version strings containing more than three parts ' 'cannot be parsed')
+        msg = 'Version strings containing more than three parts cannot be parsed'
+        raise ValueError(msg)
 
-    vals: List[int] = []
+    vals: list[int] = []
     for item in split_v:
         if item.isnumeric():
             vals.append(int(item))
@@ -177,24 +183,26 @@ def meets_version(version: str, meets: str) -> bool:
 
     >>> meets_version('0.26.0', '0.25.2')
     True
+
     """
     va = version_tuple(version)
     vb = version_tuple(meets)
 
     if len(va) != len(vb):
-        raise AssertionError("Versions are not comparable.")
+        msg = 'Versions are not comparable.'
+        raise AssertionError(msg)
 
     for i in range(len(va)):
         if va[i] > vb[i]:
             return True
-        elif va[i] < vb[i]:
+        if va[i] < vb[i]:
             return False
 
     # Arrived here if same version
     return True
 
 
-def get_filesystem_type() -> Union[str, Literal[False]]:
+def get_filesystem_type() -> str | Literal[False]:
     """Get the type of the file system at the path of the scooby package."""
     try:
         import psutil  # lazy-load see PR#85
@@ -204,12 +212,12 @@ def get_filesystem_type() -> Union[str, Literal[False]]:
     import platform  # lazy-load see PR#85
 
     # Skip Windows due to https://github.com/banesullivan/scooby/issues/75
-    fs_type: Union[str, Literal[False]]
+    fs_type: str | Literal[False]
     if psutil and platform.system() != 'Windows':
         # Code by https://stackoverflow.com/a/35291824/10504481
         my_path = str(Path(__file__).resolve())
-        best_match = ""
-        fs_type = ""
+        best_match = ''
+        fs_type = ''
         for part in psutil.disk_partitions():
             if my_path.startswith(part.mountpoint) and len(best_match) < len(part.mountpoint):
                 fs_type = part.fstype
