@@ -1,11 +1,20 @@
 """The main module containing the `Report` class."""
 
+from __future__ import annotations
+
+from datetime import datetime, timezone
 import importlib
-from importlib.metadata import PackageNotFoundError, distribution, version as importlib_version
+from importlib.metadata import (
+    PackageNotFoundError,
+    distribution,
+    distributions,
+    version as importlib_version,
+)
+import json
+import re
 import sys
-import time
 from types import ModuleType
-from typing import Any, Dict, List, Literal, Optional, Tuple, Union, cast
+from typing import Any, Literal, cast
 
 from .knowledge import (
     PACKAGE_ALIASES,
@@ -25,10 +34,10 @@ VERSION_NOT_FOUND = 'Version unknown'
 class PlatformInfo:
     """Internal helper class to access details about the computer platform."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Initialize."""
-        self._mkl_info: Optional[str]  # for typing purpose
-        self._filesystem: Union[str, Literal[False]]
+        self._mkl_info: str | None  # for typing purpose
+        self._filesystem: str | Literal[False]
 
     @property
     def system(self) -> str:
@@ -42,21 +51,21 @@ class PlatformInfo:
             try:
                 s += (
                     f' ({platform().freedesktop_os_release()["NAME"]} '
-                    + f'{platform().freedesktop_os_release()["VERSION_ID"]})'
+                    f'{platform().freedesktop_os_release()["VERSION_ID"]})'
                 )
-            except Exception:
+            except Exception:  # noqa: BLE001
                 pass
         elif s == 'Windows':
             try:
                 release, version, csd, ptype = platform().win32_ver()
                 s += f' ({release} {version} {csd} {ptype})'
-            except Exception:
+            except Exception:  # noqa: BLE001
                 pass
         elif s == 'Darwin':
             try:
                 release, _, _ = platform().mac_ver()
                 s += f' (macOS {release})'
-            except Exception:
+            except Exception:  # noqa: BLE001
                 pass
         elif s == 'Java':
             # TODO: parse platform().java_ver()
@@ -101,14 +110,14 @@ class PlatformInfo:
                 import psutil  # lazy-load see PR#85
 
                 tmem = psutil.virtual_memory().total
-                self._total_ram = '{:.1f} GiB'.format(tmem / (1024.0**3))
+                self._total_ram = f'{tmem / (1024.0**3):.1f} GiB'
             except ImportError:
                 self._total_ram = 'unknown'
 
         return self._total_ram
 
     @property
-    def mkl_info(self) -> Optional[str]:
+    def mkl_info(self) -> str | None:
         """Return MKL info.
 
         If not available, returns 'unknown'.
@@ -129,9 +138,9 @@ class PlatformInfo:
 
             # Get mkl info from numexpr or mkl, if available
             if mkl:
-                self._mkl_info = cast(str, mkl.get_version_string())
+                self._mkl_info = cast('str', mkl.get_version_string())
             elif numexpr:
-                self._mkl_info = cast(str, numexpr.get_vml_version())
+                self._mkl_info = cast('str', numexpr.get_vml_version())
             else:
                 self._mkl_info = None
 
@@ -140,10 +149,11 @@ class PlatformInfo:
     @property
     def date(self) -> str:
         """Return the date formatted as a string."""
-        return time.strftime('%a %b %d %H:%M:%S %Y %Z')
+        now_utc = datetime.now(timezone.utc)
+        return now_utc.strftime('%a %b %d %H:%M:%S %Y %Z')
 
     @property
-    def filesystem(self) -> Union[str, Literal[False]]:
+    def filesystem(self) -> str | Literal[False]:
         """Get the type of the file system at the path of the scooby package."""
         if not hasattr(self, '_filesystem'):
             self._filesystem = get_filesystem_type()
@@ -155,13 +165,13 @@ class PythonInfo:
 
     def __init__(
         self,
-        additional: Optional[List[Union[str, ModuleType]]],
-        core: Optional[List[Union[str, ModuleType]]],
-        optional: Optional[List[Union[str, ModuleType]]],
+        additional: list[str | ModuleType] | None,
+        core: list[str | ModuleType] | None,
+        optional: list[str | ModuleType] | None,
         sort: bool,
-    ):
+    ) -> None:
         """Initialize python info."""
-        self._packages: Dict[str, Any] = {}  # Holds name of packages and their version
+        self._packages: dict[str, Any] = {}  # Holds name of packages and their version
         self._sort = sort
 
         # Add packages in the following order:
@@ -170,16 +180,18 @@ class PythonInfo:
         self._add_packages(optional, optional=True)  # Optional packages
 
     def _add_packages(
-        self, packages: Optional[List[Union[str, ModuleType]]], optional: bool = False
-    ):
+        self,
+        packages: list[str | ModuleType] | None,
+        optional: bool = False,
+    ) -> None:
         """Add all packages to list; optional ones only if available."""
         # Ensure arguments are a list
         if isinstance(packages, (str, ModuleType)):
-            pckgs: List[Union[str, ModuleType]] = [
+            pckgs: list[str | ModuleType] = [
                 packages,
             ]
         elif packages is None or len(packages) < 1:
-            pckgs = list()
+            pckgs = []
         else:
             pckgs = list(packages)
 
@@ -199,25 +211,58 @@ class PythonInfo:
         """Return the python environment."""
         if in_ipykernel():
             return 'Jupyter'
-        elif in_ipython():
+        if in_ipython():
             return 'IPython'
         return 'Python'
 
     @property
-    def packages(self) -> Dict[str, Any]:
-        """Return versions of all packages.
+    def packages(self) -> dict[str, Any]:
+        """Return versions of all additional, core, and optional packages.
 
         Includes available and unavailable/unknown.
 
         """
         pckg_dict = dict(self._packages)
         if self._sort:
-            packages: Dict[str, Any] = {}
+            packages: dict[str, Any] = {}
             for name in sorted(pckg_dict.keys(), key=lambda x: x.lower()):
                 packages[name] = pckg_dict[name]
             pckg_dict = packages
         return pckg_dict
 
+    @property
+    def installed_packages(self) -> dict[str, str]:
+        """Return versions of all installed packages.
+
+        .. versionadded:: 0.11
+        """
+        # sort case-insensitively by name
+        installed = sorted(
+            (dist.metadata['Name'] for dist in distributions()),
+            key=str.lower,
+        )
+        packages: dict[str, str] = {}
+        for pkg in installed:
+            name, version = get_version(pkg)
+            packages[name] = version
+        return packages
+
+    @property
+    def other_packages(self) -> dict[str, str]:
+        """Packages which are installed but not labeled as additional, core, or optional.
+
+        This is effectively ``installed_packages`` - ``packages``.
+
+        .. versionadded:: 0.11
+        """
+        packages = self.packages
+        installed: dict[str, str] = self.installed_packages
+        other: dict[str, str] = installed.copy()
+        for key in installed:
+            if key in packages:
+                other.pop(key)
+        return other
+
 
 # The main Report instance
 class Report(PlatformInfo, PythonInfo):
@@ -255,18 +300,25 @@ class Report(PlatformInfo, PythonInfo):
     max_width : int, optional
         Max-width of html-table. By default None.
 
+    show_other : bool, default: False
+        Show all other installed packages not already included in ``additional``,
+        ``core``, or ``other``. These packages are always sorted alphabetically.
+
+        .. versionadded:: 0.11
+
     """
 
     def __init__(
         self,
-        additional: Optional[List[Union[str, ModuleType]]] = None,
-        core: Optional[List[Union[str, ModuleType]]] = None,
-        optional: Optional[List[Union[str, ModuleType]]] = None,
+        additional: list[str | ModuleType] | None = None,
+        core: list[str | ModuleType] | None = None,
+        optional: list[str | ModuleType] | None = None,
         ncol: int = 4,
         text_width: int = 80,
         sort: bool = False,
-        extra_meta: Optional[Union[Tuple[Tuple[str, str], ...], List[Tuple[str, str]]]] = None,
-        max_width: Optional[int] = None,
+        extra_meta: tuple[tuple[str, str], ...] | list[tuple[str, str]] | None = None,
+        max_width: int | None = None,
+        show_other: bool = False,
     ) -> None:
         """Initialize report."""
         # Set default optional packages to investigate
@@ -277,25 +329,33 @@ class Report(PlatformInfo, PythonInfo):
         self.ncol = int(ncol)
         self.text_width = int(text_width)
         self.max_width = max_width
+        self.show_other = show_other
 
         if extra_meta is not None:
             if not isinstance(extra_meta, (list, tuple)):
-                raise TypeError("`extra_meta` must be a list/tuple of " "key-value pairs.")
+                msg = '`extra_meta` must be a list/tuple of key-value pairs.'
+                raise TypeError(msg)
             if len(extra_meta) == 2 and isinstance(extra_meta[0], str):
                 extra_meta = [extra_meta]
             for meta in extra_meta:
                 if not isinstance(meta, (list, tuple)) or len(meta) != 2:
-                    raise TypeError("Each chunk of meta info must have two values.")
+                    msg = 'Each chunk of meta info must have two values.'
+                    raise TypeError(msg)
         else:
             extra_meta = []
         self._extra_meta = extra_meta
 
     def __repr__(self) -> str:
         """Return Plain-text version information."""
+
+        def line_sep(sep: str = '-', *, newlines: bool = False) -> str:
+            line = self.text_width * sep
+            return '\n' + line + '\n' if newlines else line
+
         import textwrap  # lazy-load see PR#85
 
         # Width for text-version
-        text = '\n' + self.text_width * '-' + '\n'
+        text = line_sep(newlines=True)
 
         # Date and time info as title
         date_text = '  Date: '
@@ -314,7 +374,15 @@ class Report(PlatformInfo, PythonInfo):
 
         # Platform/OS details
         repr_dict = self.to_dict()
-        for key in ['OS', 'CPU(s)', 'Machine', 'Architecture', 'RAM', 'Environment', 'File system']:
+        for key in [
+            'OS',
+            'CPU(s)',
+            'Machine',
+            'Architecture',
+            'RAM',
+            'Environment',
+            'File system',
+        ]:
             if key in repr_dict:
                 text += f'{key:>{row_width}} : {repr_dict[key]}\n'
         for key, value in self._extra_meta:
@@ -328,8 +396,9 @@ class Report(PlatformInfo, PythonInfo):
             text += '\n'
 
         # Loop over packages
+        package_template = '{name:>{row_width}} : {version}\n'
         for name, version in self.packages.items():
-            text += f'{name:>{row_width}} : {version}\n'
+            text += package_template.format(name=name, version=version, row_width=row_width)
 
         # MKL details
         if self.mkl_info:
@@ -337,8 +406,15 @@ class Report(PlatformInfo, PythonInfo):
             for txt in textwrap.wrap(self.mkl_info, self.text_width - 4):
                 text += '  ' + txt + '\n'
 
+        if self.show_other:
+            text = text.rstrip()
+            text += line_sep('·', newlines=True)
+
+            for name, version in self.other_packages.items():
+                text += package_template.format(name=name, version=version, row_width=row_width)
+
         # Finish
-        text += self.text_width * '-'
+        text += line_sep()
 
         return text
 
@@ -349,59 +425,67 @@ class Report(PlatformInfo, PythonInfo):
 
         def colspan(html: str, txt: str, ncol: int, nrow: int) -> str:
             r"""Print txt in a row spanning whole table."""
-            html += "  <tr>\n"
+            html += '  <tr>\n'
             html += "     <td style='"
             if ncol == 1:
-                html += "text-align: left; "
+                html += 'text-align: left; '
             else:
-                html += "text-align: center; "
+                html += 'text-align: center; '
             if nrow == 0:
-                html += "font-weight: bold; font-size: 1.2em; "
+                html += 'font-weight: bold; font-size: 1.2em; '
             html += border + " colspan='"
             html += f"{2 * ncol}'>{txt}</td>\n"
-            html += "  </tr>\n"
+            html += '  </tr>\n'
             return html
 
-        def cols(html: str, version: str, name: str, ncol: int, i: int) -> Tuple[str, int]:
+        def cols(html: str, version: str, name: str, ncol: int, i: int) -> tuple[str, int]:
             r"""Print package information in two cells."""
             # Check if we have to start a new row
             if i > 0 and i % ncol == 0:
-                html += "  </tr>\n"
-                html += "  <tr>\n"
+                html += '  </tr>\n'
+                html += '  <tr>\n'
 
-            align = "left" if ncol == 1 else "right"
+            align = 'left' if ncol == 1 else 'right'
             html += f"    <td style='text-align: {align};"
-            html += " " + border + ">%s</td>\n" % name
+            html += ' ' + border + f'>{name}</td>\n'
 
             html += "    <td style='text-align: left; "
-            html += border + ">%s</td>\n" % version
+            html += border + f'>{version}</td>\n'
 
             return html, i + 1
 
         # Start html-table
         html = "<table style='border: 1.5px solid;"
         if self.max_width:
-            html += f" max-width: {self.max_width}px;"
+            html += f' max-width: {self.max_width}px;'
         html += "'>\n"
 
         # Date and time info as title
         html = colspan(html, self.date, self.ncol, 0)
 
         # Platform/OS details
-        html += "  <tr>\n"
+        html += '  <tr>\n'
         repr_dict = self.to_dict()
         i = 0
-        for key in ['OS', 'CPU(s)', 'Machine', 'Architecture', 'RAM', 'Environment', "File system"]:
+        for key in [
+            'OS',
+            'CPU(s)',
+            'Machine',
+            'Architecture',
+            'RAM',
+            'Environment',
+            'File system',
+        ]:
             if key in repr_dict:
                 html, i = cols(html, repr_dict[key], key, self.ncol, i)
         for meta in self._extra_meta:
             html, i = cols(html, meta[1], meta[0], self.ncol, i)
         # Finish row
-        html += "  </tr>\n"
+        html += '  </tr>\n'
 
         # Python details
         html = colspan(html, 'Python ' + self.sys_version, self.ncol, 1)
-        html += "  <tr>\n"
+        html += '  <tr>\n'
 
         # Loop over packages
         i = 0  # Reset count for rows.
@@ -409,24 +493,24 @@ class Report(PlatformInfo, PythonInfo):
             html, i = cols(html, version, name, self.ncol, i)
         # Fill up the row
         while i % self.ncol != 0:
-            html += "    <td style= " + border + "></td>\n"
-            html += "    <td style= " + border + "></td>\n"
+            html += '    <td style= ' + border + '></td>\n'
+            html += '    <td style= ' + border + '></td>\n'
             i += 1
         # Finish row
-        html += "  </tr>\n"
+        html += '  </tr>\n'
 
         # MKL details
         if self.mkl_info:
             html = colspan(html, self.mkl_info, self.ncol, 2)
 
         # Finish
-        html += "</table>"
+        html += '</table>'
 
         return html
 
-    def to_dict(self) -> Dict[str, str]:
+    def to_dict(self) -> dict[str, str]:
         """Return report as dict for storage."""
-        out: Dict[str, str] = {}
+        out: dict[str, str] = {}
 
         # Date and time info
         out['Date'] = self.date
@@ -448,8 +532,9 @@ class Report(PlatformInfo, PythonInfo):
         out['Python'] = self.sys_version
 
         # Loop over packages
-        for name, version in self._packages.items():
-            out[name] = version
+        out.update(self._packages)
+
+        out['other'] = json.dumps(self.other_packages)
 
         # MKL details
         if self.mkl_info:
@@ -464,29 +549,44 @@ class AutoReport(Report):
     This will generate a report based on the distribution requirements of the package.
     """
 
-    def __init__(self, module, additional=None, ncol=3, text_width=80, sort=False):
+    def __init__(
+        self,
+        module: str | ModuleType,
+        additional: str | None = None,
+        ncol: int = 3,
+        text_width: int = 80,
+        sort: bool = False,
+        show_other: bool = False,
+    ) -> None:
         """Initialize."""
         if not isinstance(module, (str, ModuleType)):
-            raise TypeError("Cannot generate report for type " "({})".format(type(module)))
+            msg = f'Cannot generate report for type ({type(module)})'
+            raise TypeError(msg)
 
         if isinstance(module, ModuleType):
             module = module.__name__
 
         # Autogenerate from distribution requirements
-        core = [module, *get_distribution_dependencies(module)]
+        deps = get_distribution_dependencies(module, separate_extras=True)
+        core = [module, *deps.pop('core')]
+        optional = [  # flatten all extras from the nested "optional" dict
+            pkg for dep_list in deps['optional'].values() for pkg in dep_list
+        ]
+
         Report.__init__(
             self,
             additional=additional,
             core=core,
-            optional=[],
+            optional=optional,
             ncol=ncol,
             text_width=text_width,
             sort=sort,
+            show_other=show_other,
         )
 
 
 # This functionaliy might also be of interest on its own.
-def get_version(module: Union[str, ModuleType]) -> Tuple[str, Optional[str]]:
+def get_version(module: str | ModuleType) -> tuple[str, str | None]:
     """Get the version of ``module`` by passing the package or it's name.
 
     Parameters
@@ -502,10 +602,12 @@ def get_version(module: Union[str, ModuleType]) -> Tuple[str, Optional[str]]:
 
     version : str or None
         Version of module.
+
     """
     # module is (1) a module or (2) a string.
     if not isinstance(module, (str, ModuleType)):
-        raise TypeError("Cannot fetch version from type " "({})".format(type(module)))
+        msg = f'Cannot fetch version from type ({type(module)})'
+        raise TypeError(msg)
 
     # module is module; get name
     if isinstance(module, ModuleType):
@@ -530,14 +632,14 @@ def get_version(module: Union[str, ModuleType]) -> Tuple[str, Optional[str]]:
             module = importlib.import_module(name)
         except ImportError:
             return name, MODULE_NOT_FOUND
-        except Exception:
+        except Exception:  # noqa: BLE001
             return name, MODULE_TROUBLE
 
     # Try common version names on loaded module
     for v_string in ('__version__', 'version'):
         try:
             return name, getattr(module, v_string)
-        except AttributeError:
+        except AttributeError:  # noqa: PERF203
             pass
 
     # Try the VERSION_ATTRIBUTES library
@@ -565,21 +667,64 @@ def platform() -> ModuleType:
     return platform
 
 
-def get_distribution_dependencies(dist_name: str):
-    """Get the dependencies of a specified package distribution.
+def get_distribution_dependencies(
+    dist_name: str,
+    *,
+    separate_extras: bool = False,
+) -> list[str] | dict[str, list[str]]:
+    """Get required and extra dependencies of a package distribution.
 
     Parameters
     ----------
     dist_name : str
         Name of the package distribution.
 
+    separate_extras : bool, default: False
+        Separate extra (optional) dependencies by name. If ``True`` a ``dict``
+        is returned with a ``'core'`` key with all required dependencies,
+        and a ``'optional'`` key which includes any extras as separate keys.
+
+        .. versionadded:: 0.11
+
     Returns
     -------
-    dependencies : list
-        List of dependency names.
+    dependencies : list | dict[str, list[str]]
+        List of dependency names, or dict of dependencies separated by extras
+        name if ``separate_extras`` is ``True``.
+
     """
     try:
         dist = distribution(dist_name)
     except PackageNotFoundError:
-        raise PackageNotFoundError(f"Package `{dist_name}` has no distribution.")
-    return [pkg.split()[0] for pkg in dist.requires]
+        msg = f'Package `{dist_name}` has no distribution.'
+        raise PackageNotFoundError(msg) from None
+
+    def _package_name(requirement: str) -> str:
+        for sep in (' ', ';', '<', '=', '>', '!'):
+            requirement = requirement.split(sep, 1)[0]
+        return requirement.strip()
+
+    requires = dist.requires or []
+    if not separate_extras:
+        # Use dict for ordered and unique keys
+        return list({_package_name(pkg): None for pkg in requires}.keys())
+
+    deps_dict: dict[str, dict[str, None | dict[str, None]]] = {'core': {}, 'optional': {}}
+
+    for req in requires:
+        name = _package_name(req)
+        # Extract the extra name from a requirement string like "extra == 'dev'"
+        extras_match = re.search(r"extra\s*==\s*['\"]?([\w-]+)['\"]?", req)
+        if extras_match:
+            extra_name = extras_match.group(1)
+            if extra_name not in deps_dict['optional']:
+                deps_dict['optional'][extra_name] = {}
+            deps_dict['optional'][extra_name][name] = None
+        else:
+            deps_dict['core'][name] = None
+
+    # Convert dicts of names → lists while preserving order
+    return {
+        'core': list(deps_dict['core'].keys()),
+        'optional': {k: list(v.keys()) for k, v in deps_dict['optional'].items() if v},
+    }
