@@ -1,14 +1,20 @@
 """Track imports."""
 
-from types import ModuleType
-from typing import List, Mapping, Optional, Sequence, Set, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from scooby.knowledge import get_standard_lib_modules
 from scooby.report import Report
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping, Sequence
+    from types import ModuleType
+
+
 TRACKING_SUPPORTED = False
 SUPPORT_MESSAGE = (
-    "Tracking is not supported for this version of Python. " "Try using a modern version of Python."
+    'Tracking is not supported for this version of Python. Try using a modern version of Python.'
 )
 try:
     import builtins
@@ -19,42 +25,40 @@ except (ImportError, AttributeError):
     pass
 
 # The variable we track all imports in
-TRACKED_IMPORTS: List[Union[str, ModuleType]] = ["scooby"]
+TRACKED_IMPORTS: list[str | ModuleType] = ['scooby']
 
 MODULES_TO_IGNORE = {
-    "pyMKL",
-    "mkl",
-    "vtkmodules",
-    "mpl_toolkits",
+    'pyMKL',
+    'mkl',
+    'vtkmodules',
+    'mpl_toolkits',
 }
 
 
-STDLIB_PKGS: Optional[Set[str]] = None
+STDLIB_PKGS: set[str] = set()
 
 
-def _criterion(name: str):
-    if (
+def _criterion(name: str) -> bool:
+    return (
         len(name) > 0
         and name not in STDLIB_PKGS
-        and not name.startswith("_")
+        and not name.startswith('_')
         and name not in MODULES_TO_IGNORE
-    ):
-        return True
-    return False
+    )
 
 
 if TRACKING_SUPPORTED:
 
     def scooby_import(
         name: str,
-        globals: Optional[Mapping[str, object]] = None,
-        locals: Optional[Mapping[str, object]] = None,
+        globals: Mapping[str, object] | None = None,  # noqa: A002
+        locals: Mapping[str, object] | None = None,  # noqa: A002
         fromlist: Sequence[str] = (),
         level: int = 0,
     ) -> ModuleType:
         """Override of the import method to track package names."""
         m = CLASSIC_IMPORT(name, globals=globals, locals=locals, fromlist=fromlist, level=level)
-        name = name.split(".")[0]
+        name = name.split('.')[0]
         if level == 0 and _criterion(name):
             TRACKED_IMPORTS.append(name)
         return m
@@ -67,7 +71,6 @@ def track_imports() -> None:
     global STDLIB_PKGS
     STDLIB_PKGS = get_standard_lib_modules()
     builtins.__import__ = scooby_import
-    return
 
 
 def untrack_imports() -> None:
@@ -79,8 +82,7 @@ def untrack_imports() -> None:
         raise RuntimeError(SUPPORT_MESSAGE)
     builtins.__import__ = CLASSIC_IMPORT
     TRACKED_IMPORTS.clear()
-    TRACKED_IMPORTS.append("scooby")
-    return
+    TRACKED_IMPORTS.append('scooby')
 
 
 class TrackedReport(Report):
@@ -92,19 +94,22 @@ class TrackedReport(Report):
 
     def __init__(
         self,
-        additional: Optional[List[Union[str, ModuleType]]] = None,
+        additional: list[str | ModuleType] | None = None,
         ncol: int = 3,
         text_width: int = 80,
         sort: bool = False,
-    ):
+    ) -> None:
         """Initialize."""
         if not TRACKING_SUPPORTED:
             raise RuntimeError(SUPPORT_MESSAGE)
         if len(TRACKED_IMPORTS) < 2:
+            msg = (
+                'There are no tracked imports, please use '
+                '`scooby.track_imports()` before running your '
+                'code.'
+            )
             raise RuntimeError(
-                "There are no tracked imports, please use "
-                "`scooby.track_imports()` before running your "
-                "code."
+                msg,
             )
 
         Report.__init__(
